@@ -2,21 +2,33 @@
 # gnatsweb-site.pl -
 #     Gnatsweb site-specific variables and subroutines.
 #
-# $Id: gnatsweb-site-sente.pl,v 1.18 1999/09/30 17:54:30 kenstir Exp $
+# $Id: gnatsweb-site-sente.pl,v 1.24 1999/11/19 18:50:56 kenstir Exp $
+
+# Gnats host.
+$site_gnats_host = 'gnats.senteinc.com';
 
 # Name you want in the page banner.
 $site_banner_text = 'Sente gnatsweb';
 
 # Make gnatsweb appear different if I'm running a test version,
 # so I know where I am.
-if (($ENV{'SCRIPT_NAME'} =~ m@/cgi-bin/gnatsweb/@) # running in test subdir
-    || ($ENV{'REMOTE_ADDR'} eq '127.0.0.1'))       # testing @ home
+if (($ENV{'SCRIPT_NAME'} =~ m@/cgi-bin/gnatsweb/@)   # running in test subdir
+    || ($ENV{'REMOTE_ADDR'} eq '127.0.0.1')) # testing @ home
 {
     $site_banner_text = 'TEST VERSION OF GNATSWEB';
     $site_banner_background = 'red';
     $site_background = 'bisque';
 }
 
+# Turn on special checking for Doug MacEachern's modperl
+if (exists $ENV{'GATEWAY_INTERFACE'} 
+    && ($MOD_PERL = $ENV{'GATEWAY_INTERFACE'} =~ /^CGI-Perl\//))
+{
+    $site_banner_text = 'mod_perl TEST';
+    $site_banner_background = 'orange';
+    $site_background = '#c0ffc0';
+}
+
 # Make sure nobody tries to swamp our server with a huge file attachment.
 $site_post_max = 2000000; # 2Mb
 
@@ -32,23 +44,36 @@ sub site_callback {
     # system log, e.g. /var/log/httpd/error_log
     #warn "site_callback: @_\n";
 
-    if ($reason eq 'sendpr_description')
+    if ($reason eq 'main_page_top_buttons')
     {
-        # default Description text
-        return 
-" Customer?: <yes/no>
- Company: <company_name>
- Contact: <contact_name>
- Email: <address>
-";
+        # Add buttons to the top of the main page.
+        my $form = one_line_form('Open Support Issue:',
+                             submit('cmd', 'create'),
+                             hidden('Class', 'support'),
+                             hidden('Submitter-Id', 'sente'));
+        return $form;
+    }
+    #elsif ($reason eq 'main_page_bottom_buttons')
+    #{}
+    elsif ($reason eq 'get_default_value')
+    {
+        my $default_what = shift(@args);
+        if ($default_what eq 'email') {
+            return "$ENV{'REMOTE_USER'}\@senteinc.com";
+        }
     }
     elsif ($reason eq 'sendpr_fix')
     {
         # default Fix text
-        return 
-" Fix for: 
- Fixed in: 
-";
+        return " Fix for: \n Fixed in: \n";
+    }
+    elsif ($reason =~ /^(sendpr|edit)_intro_description$/)
+    {
+        # Stuff to include on top of the Description textarea.
+        my $new_frame = "frame" . $q->escape(scalar(localtime()));
+        my $stuff = "Description should include contact info; "
+            . "<br>";
+        return $stuff;
     }
     elsif ($reason eq 'initialize')
     {
