@@ -3,7 +3,7 @@
 # gnats-test.pl -
 #      Test code for gnats-lib.pl
 #
-# $Id: test.pl,v 2.5 1999/07/27 16:03:23 kenstir Exp $
+# $Id: test.pl,v 1.14 1999/11/15 15:14:30 kenstir Exp $
 
 #-----------------------------------------------------------------------------
 # test harness setup
@@ -15,7 +15,9 @@ getopts('d');
 
 $suppress_main = 1;
 do 'gnatsweb.pl';
-do 'gnatsweb-site.pl' if (-e 'gnatsweb-site.pl');
+die $@ if $@;
+do './gnatsweb-site.pl' if (-e './gnatsweb-site.pl');
+die $@ if $@;
 
 $errors = 0;
 
@@ -25,9 +27,9 @@ open(LOG, ">test.log") || die;
 $client_cmd_debug = $opt_d;
 
 # get connection info from environment
-$user     = $ENV{'USERNAME'} || 'anonymous';
-$password = $ENV{'PASSWORD'} || 'guest';
-$database = $ENV{'DATABASE'} || 'main';
+$db_prefs{'user'}         = $ENV{'USERNAME'} || 'anonymous';
+$db_prefs{'password'}     = $ENV{'PASSWORD'} || 'guest';
+$global_prefs{'database'} = $ENV{'DATABASE'} || 'main';
 
 #-----------------------------------------------------------------------------
 # support subs
@@ -88,7 +90,13 @@ map { $_ = (split/\|/, $_)[0] } @query_results;
 @query_results = sort { $a <=> $b } @query_results;
 
 # trim it to 50 PR's max
-splice(@query_results, 49);
+if ($ENV{'LOGNAME'} ne 'kenstir') {
+    splice(@query_results, 49);
+} else {
+    # kenstir-special test.
+    #splice(@query_results, 49);
+    #@query_results = (42,43,44);
+}
 
 foreach my $mypr (@query_results) {
     $test = "parsepr/unparsepr $mypr";
